@@ -12,7 +12,7 @@ def unicode2utf8(input=None):
         for key in keys:
             value = input[key]
             del(input[key])
-            input[unicode2utf8(key)] = unicode2utf8(value)
+            input[str(unicode2utf8(key))] = unicode2utf8(value)
         return input
     elif data_type == type([]):
         for i in range(len(input)):
